@@ -28,7 +28,6 @@ Array writers may be able to scale the array or apply an intercept, or do
 something else to make sense of conversions between float and int, or between
 larger ints and smaller.
 """
-from __future__ import division, absolute_import
 
 import warnings
 
@@ -50,7 +49,7 @@ class ScalingError(WriterError):
 class ArrayWriter(object):
 
     def __init__(self, array, out_dtype=None, **kwargs):
-        """ Initialize array writer
+        r""" Initialize array writer
 
         Parameters
         ----------
@@ -247,7 +246,7 @@ class SlopeArrayWriter(ArrayWriter):
 
     def __init__(self, array, out_dtype=None, calc_scale=True,
                  scaler_dtype=np.float32, **kwargs):
-        """ Initialize array writer
+        r""" Initialize array writer
 
         Parameters
         ----------
@@ -478,7 +477,7 @@ class SlopeInterArrayWriter(SlopeArrayWriter):
 
     def __init__(self, array, out_dtype=None, calc_scale=True,
                  scaler_dtype=np.float32, **kwargs):
-        """ Initialize array writer
+        r""" Initialize array writer
 
         Parameters
         ----------
@@ -751,7 +750,7 @@ def get_slope_inter(writer):
 
 def make_array_writer(data, out_type, has_slope=True, has_intercept=True,
                       **kwargs):
-    """ Make array writer instance for array `data` and output type `out_type`
+    r""" Make array writer instance for array `data` and output type `out_type`
 
     Parameters
     ----------
