@@ -6,11 +6,10 @@
 #   copyright and license terms.
 #
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
-''' Common interface for any image format--volume or surface, binary or xml.'''
+""" Common interface for any image format--volume or surface, binary or xml."""
 
 import io
 from copy import deepcopy
-from six import string_types
 from .fileholders import FileHolder
 from .filename_parser import (types_filenames, TypesFilenamesError,
                               splitext_addext)
@@ -23,7 +22,7 @@ class ImageFileError(Exception):
 
 
 class FileBasedHeader(object):
-    ''' Template class to implement header protocol '''
+    """ Template class to implement header protocol """
 
     @classmethod
     def from_header(klass, header=None):
@@ -35,8 +34,8 @@ class FileBasedHeader(object):
         # different field names
         if type(header) == klass:
             return header.copy()
-        raise NotImplementedError("Header class requires a conversion"
-                                  " from %s to %s" % (klass, type(header)))
+        raise NotImplementedError("Header class requires a conversion "
+                                  f"from {klass} to {type(header)}")
 
     @classmethod
     def from_fileobj(klass, fileobj):
@@ -52,16 +51,16 @@ class FileBasedHeader(object):
         return not self == other
 
     def copy(self):
-        ''' Copy object to independent representation
+        """ Copy object to independent representation
 
         The copy should not be affected by any changes to the original
         object.
-        '''
+        """
         return deepcopy(self)
 
 
 class FileBasedImage(object):
-    '''
+    """
     Abstract image class with interface for loading/saving images from disk.
 
     The class doesn't define any image properties.
@@ -121,7 +120,7 @@ class FileBasedImage(object):
 
     You can get the data out again with::
 
-        img.get_data()
+        img.get_fdata()
 
     Less commonly, for some image types that support it, you might want to
     fetch out the unscaled array via the object containing the data::
@@ -163,7 +162,7 @@ class FileBasedImage(object):
     carry the position at which a write (with ``to_files``) should place the
     data.  The ``file_map`` contents should therefore be such, that this will
     work:
-    '''
+    """
     header_class = FileBasedHeader
     _meta_sniff_len = 0
     files_types = (('image', None),)
@@ -174,7 +173,7 @@ class FileBasedImage(object):
     rw = True  # Used in test code
 
     def __init__(self, header=None, extra=None, file_map=None):
-        ''' Initialize image
+        """ Initialize image
 
         The image is a combination of (header), with
         optional metadata in `extra`, and filename / file-like objects
@@ -189,7 +188,7 @@ class FileBasedImage(object):
            metadata of this image type
         file_map : mapping, optional
            mapping giving file information for this image format
-        '''
+        """
         self._header = self.header_class.from_header(header)
         if extra is None:
             extra = {}
@@ -204,8 +203,8 @@ class FileBasedImage(object):
         return self._header
 
     def __getitem__(self):
-        ''' No slicing or dictionary interface for images
-        '''
+        """ No slicing or dictionary interface for images
+        """
         raise TypeError("Cannot slice image objects.")
 
     @deprecate_with_version('get_header method is deprecated.\n'
@@ -218,7 +217,7 @@ class FileBasedImage(object):
         return self.header
 
     def get_filename(self):
-        ''' Fetch the image filename
+        """ Fetch the image filename
 
         Parameters
         ----------
@@ -231,7 +230,7 @@ class FileBasedImage(object):
            If an image may have several filenames associated with it (e.g.
            Analyze ``.img, .hdr`` pair) then we return the more characteristic
            filename (the ``.img`` filename in the case of Analyze')
-        '''
+        """
         # which filename is returned depends on the ordering of the
         # 'files_types' class attribute - we return the name
         # corresponding to the first in that tuple
@@ -239,7 +238,7 @@ class FileBasedImage(object):
         return self.file_map[characteristic_type].filename
 
     def set_filename(self, filename):
-        ''' Sets the files in the object from a given filename
+        """ Sets the files in the object from a given filename
 
         The different image formats may check whether the filename has
         an extension characteristic of the format, and raise an error if
@@ -247,12 +246,12 @@ class FileBasedImage(object):
 
         Parameters
         ----------
-        filename : str
+        filename : str or os.PathLike
            If the image format only has one file associated with it,
            this will be the only filename set into the image
            ``.file_map`` attribute. Otherwise, the image instance will
            try and guess the other filenames from this given filename.
-        '''
+        """
         self.file_map = self.__class__.filespec_to_file_map(filename)
 
     @classmethod
@@ -280,7 +279,7 @@ class FileBasedImage(object):
 
         Parameters
         ----------
-        filespec : str
+        filespec : str or os.PathLike
             Filename that might be for this image file type.
 
         Returns
@@ -302,8 +301,7 @@ class FileBasedImage(object):
                 trailing_suffixes=klass._compressed_suffixes)
         except TypesFilenamesError:
             raise ImageFileError(
-                'Filespec "{0}" does not look right for class {1}'.format(
-                    filespec, klass))
+                f'Filespec "{filespec}" does not look right for class {klass}')
         file_map = {}
         for key, fname in filenames.items():
             file_map[key] = FileHolder(filename=fname)
@@ -318,11 +316,11 @@ class FileBasedImage(object):
         return klass.filespec_to_file_map(filespec)
 
     def to_filename(self, filename):
-        ''' Write image to files implied by filename string
+        """ Write image to files implied by filename string
 
         Parameters
         ----------
-        filename : str
+        filename : str or os.PathLike
            filename to which to save image.  We will parse `filename`
            with ``filespec_to_file_map`` to work out names for image,
            header etc.
@@ -330,7 +328,7 @@ class FileBasedImage(object):
         Returns
         -------
         None
-        '''
+        """
         self.file_map = self.filespec_to_file_map(filename)
         self.to_file_map()
 
@@ -351,7 +349,7 @@ class FileBasedImage(object):
 
     @classmethod
     def make_file_map(klass, mapping=None):
-        ''' Class method to make files holder for this image type
+        """ Class method to make files holder for this image type
 
         Parameters
         ----------
@@ -367,14 +365,14 @@ class FileBasedImage(object):
            sequence klass.files_types, and values of type FileHolder,
            where FileHolder objects have default values, other than
            those given by `mapping`
-        '''
+        """
         if mapping is None:
             mapping = {}
         file_map = {}
         for key, ext in klass.files_types:
             file_map[key] = FileHolder()
             mapval = mapping.get(key, None)
-            if isinstance(mapval, string_types):
+            if isinstance(mapval, str):
                 file_map[key].filename = mapval
             elif hasattr(mapval, 'tell'):
                 file_map[key].fileobj = mapval
@@ -384,7 +382,7 @@ class FileBasedImage(object):
 
     @classmethod
     def instance_to_filename(klass, img, filename):
-        ''' Save `img` in our own format, to name implied by `filename`
+        """ Save `img` in our own format, to name implied by `filename`
 
         This is a class method
 
@@ -394,13 +392,13 @@ class FileBasedImage(object):
 
         filename : str
            Filename, implying name to which to save image.
-        '''
+        """
         img = klass.from_image(img)
         img.to_filename(filename)
 
     @classmethod
     def from_image(klass, img):
-        ''' Class method to create new instance of own class from `img`
+        """ Class method to create new instance of own class from `img`
 
         Parameters
         ----------
@@ -411,7 +409,7 @@ class FileBasedImage(object):
         -------
         cimg : ``spatialimage`` instance
            Image, of our own class
-        '''
+        """
         raise NotImplementedError()
 
     @classmethod
@@ -420,7 +418,7 @@ class FileBasedImage(object):
 
         Parameters
         ----------
-        filename : str
+        filename : str or os.PathLike
             Filename for an image, or an image header (metadata) file.
             If `filename` points to an image data file, and the image type has
             a separate "header" file, we work out the name of the header file,
@@ -467,7 +465,7 @@ class FileBasedImage(object):
 
         Parameters
         ----------
-        filename : str
+        filename : str or os.PathLike
             Filename for an image, or an image header (metadata) file.
             If `filename` points to an image data file, and the image type has
             a separate "header" file, we work out the name of the header file,
@@ -515,7 +513,7 @@ class FileBasedImage(object):
 
 
 class SerializableImage(FileBasedImage):
-    '''
+    """
     Abstract image class for (de)serializing images to/from byte strings.
 
     The class doesn't define any image properties.
@@ -563,7 +561,7 @@ class SerializableImage(FileBasedImage):
     images) currently do not support this interface.
     For multi-file images, ``to_bytes()`` and ``from_bytes()`` must be
     overridden, and any encoding details should be documented.
-    '''
+    """
 
     @classmethod
     def from_bytes(klass, bytestring):
