@@ -426,7 +426,7 @@ def optimize_slicer(slicer, dim_len, all_full, is_slowest, stride,
         action = heuristic(slicer, dim_len, stride)
         # Check return values (we may be using a custom function)
         if action not in ('full', 'contiguous', None):
-            raise ValueError('Unexpected return %s from heuristic' % action)
+            raise ValueError(f'Unexpected return {action} from heuristic')
         if is_int and action == 'contiguous':
             raise ValueError("int index cannot be contiguous")
         # If this is the slowest changing dimension, never upgrade None or
