@@ -63,7 +63,7 @@ def cmp_pkg_version(version_str, pkg_version_str=__version__):
 
 
 def pkg_commit_hash(pkg_path=None):
-    ''' Get short form of commit hash
+    """ Get short form of commit hash
 
     Versioneer placed a ``_version.py`` file in the package directory. This file
     gets updated on installation or ``git archive``.
@@ -83,7 +83,7 @@ def pkg_commit_hash(pkg_path=None):
        Where we got the hash from - description
     hash_str : str
        short form of hash
-    '''
+    """
     versions = _version.get_versions()
     hash_str = versions['full-revisionid'][:7]
     if hasattr(_version, 'version_json'):
@@ -98,7 +98,7 @@ def pkg_commit_hash(pkg_path=None):
 
 
 def get_pkg_info(pkg_path):
-    ''' Return dict describing the context of this package
+    """ Return dict describing the context of this package
 
     Parameters
     ----------
@@ -109,7 +109,7 @@ def get_pkg_info(pkg_path):
     -------
     context : dict
        with named parameters of interest
-    '''
+    """
     src, hsh = pkg_commit_hash()
     import numpy
     return dict(
