@@ -4,7 +4,8 @@ import nibabel as nib
 
 from nibabel.testing import data_path
 from numpy.testing import assert_array_equal
-from nose.tools import assert_raises
+
+import pytest
 
 from ..utils import get_affine_from_reference
 
@@ -17,7 +18,8 @@ def test_get_affine_from_reference():
     # Get affine from an numpy array.
     assert_array_equal(get_affine_from_reference(affine), affine)
     wrong_ref = np.array([[1, 2, 3], [4, 5, 6]])
-    assert_raises(ValueError, get_affine_from_reference, wrong_ref)
+    with pytest.raises(ValueError):
+        get_affine_from_reference(wrong_ref)
 
     # Get affine from a `SpatialImage`.
     assert_array_equal(get_affine_from_reference(img), affine)
