@@ -5,7 +5,6 @@ from os.path import realpath, abspath, dirname, isfile
 
 from ..tmpdirs import InGivenDirectory
 
-from nose.tools import assert_true, assert_equal
 
 MY_PATH = abspath(__file__)
 MY_DIR = dirname(MY_PATH)
@@ -15,10 +14,10 @@ def test_given_directory():
     # Test InGivenDirectory
     cwd = getcwd()
     with InGivenDirectory() as tmpdir:
-        assert_equal(tmpdir, abspath(cwd))
-        assert_equal(tmpdir, abspath(getcwd()))
+        assert tmpdir == abspath(cwd)
+        assert tmpdir == abspath(getcwd())
     with InGivenDirectory(MY_DIR) as tmpdir:
-        assert_equal(tmpdir, MY_DIR)
-        assert_equal(realpath(MY_DIR), realpath(abspath(getcwd())))
+        assert tmpdir == MY_DIR
+        assert realpath(MY_DIR) == realpath(abspath(getcwd()))
     # We were deleting the Given directory!  Check not so now.
-    assert_true(isfile(MY_PATH))
+    assert isfile(MY_PATH)
