@@ -6,7 +6,7 @@
 #   copyright and license terms.
 #
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
-''' Test for volumeutils module '''
+""" Test for volumeutils module """
 
 import os
 from os.path import exists
@@ -57,7 +57,7 @@ from numpy.testing import (assert_array_almost_equal,
                            assert_array_equal)
 import pytest
 
-from ..testing import assert_dt_equal, assert_allclose_safely, suppress_warnings
+from nibabel.testing import nullcontext, assert_dt_equal, assert_allclose_safely, suppress_warnings
 
 #: convenience variables for numpy types
 FLOAT_TYPES = np.sctypes['float']
@@ -182,7 +182,7 @@ def test_array_from_file_mmap():
     # Test memory mapping
     shape = (2, 21)
     with InTemporaryDirectory():
-        for dt in (np.int16, np.float):
+        for dt in (np.int16, np.float64):
             arr = np.arange(np.prod(shape), dtype=dt).reshape(shape)
             with open('test.bin', 'wb') as fobj:
                 fobj.write(arr.tobytes(order='F'))
@@ -221,7 +221,7 @@ def test_array_from_file_mmap():
 
 
 def buf_chk(in_arr, out_buf, in_buf, offset):
-    ''' Write contents of in_arr into fileobj, read back, check same '''
+    """ Write contents of in_arr into fileobj, read back, check same """
     instr = b' ' * offset + in_arr.tobytes(order='F')
     out_buf.write(instr)
     out_buf.flush()
@@ -299,7 +299,7 @@ def test_array_from_file_reread():
 def test_array_to_file():
     arr = np.arange(10).reshape(5, 2)
     str_io = BytesIO()
-    for tp in (np.uint64, np.float, np.complex):
+    for tp in (np.uint64, np.float64, np.complex128):
         dt = np.dtype(tp)
         for code in '<>':
             ndt = dt.newbyteorder(code)
@@ -365,10 +365,10 @@ def test_a2f_min_max():
             assert_array_equal(data_back, [1, 1, 2, 2])
     # Check that works OK with scaling and intercept
     arr = np.arange(4, dtype=np.float32)
-    data_back = write_return(arr, str_io, np.int, 0, -1, 0.5, 1, 2)
+    data_back = write_return(arr, str_io, int, 0, -1, 0.5, 1, 2)
     assert_array_equal(data_back * 0.5 - 1, [1, 1, 2, 2])
     # Even when scaling is negative
-    data_back = write_return(arr, str_io, np.int, 0, 1, -0.5, 1, 2)
+    data_back = write_return(arr, str_io, int, 0, 1, -0.5, 1, 2)
     assert_array_equal(data_back * -0.5 + 1, [1, 1, 2, 2])
     # Check complex numbers
     arr = np.arange(4, dtype=np.complex64) + 100j
@@ -378,7 +378,7 @@ def test_a2f_min_max():
 
 
 def test_a2f_order():
-    ndt = np.dtype(np.float)
+    ndt = np.dtype(np.float64)
     arr = np.array([0.0, 1.0, 2.0])
     str_io = BytesIO()
     # order makes no difference in 1D case
@@ -393,7 +393,7 @@ def test_a2f_order():
 
 
 def test_a2f_nan2zero():
-    ndt = np.dtype(np.float)
+    ndt = np.dtype(np.float64)
     str_io = BytesIO()
     # nans set to 0 for integer output case, not float
     arr = np.array([[np.nan, 0], [0, np.nan]])
@@ -448,15 +448,15 @@ def test_a2f_offset():
     arr = np.array([[0.0, 1.0], [2.0, 3.0]])
     str_io = BytesIO()
     str_io.write(b'a' * 42)
-    array_to_file(arr, str_io, np.float, 42)
-    data_back = array_from_file(arr.shape, np.float, str_io, 42)
-    assert_array_equal(data_back, arr.astype(np.float))
+    array_to_file(arr, str_io, np.float64, 42)
+    data_back = array_from_file(arr.shape, np.float64, str_io, 42)
+    assert_array_equal(data_back, arr.astype(np.float64))
     # And that offset=None respected
     str_io.truncate(22)
     str_io.seek(22)
-    array_to_file(arr, str_io, np.float, None)
-    data_back = array_from_file(arr.shape, np.float, str_io, 22)
-    assert_array_equal(data_back, arr.astype(np.float))
+    array_to_file(arr, str_io, np.float64, None)
+    data_back = array_from_file(arr.shape, np.float64, str_io, 22)
+    assert_array_equal(data_back, arr.astype(np.float64))
 
 
 def test_a2f_dtype_default():
@@ -620,11 +620,16 @@ def test_a2f_bad_scaling():
             (0, np.nan, -np.inf, np.inf)):
         arr = np.ones((2,), dtype=in_type)
         fobj = BytesIO()
+        cm = nullcontext()
+        if (np.issubdtype(in_type, np.complexfloating) and
+                not np.issubdtype(out_type, np.complexfloating)):
+            cm = pytest.warns(np.ComplexWarning)
         if (slope, inter) == (1, 0):
-            assert_array_equal(arr,
-                               write_return(arr, fobj, out_type,
-                                            intercept=inter,
-                                            divslope=slope))
+            with cm:
+                assert_array_equal(arr,
+                                   write_return(arr, fobj, out_type,
+                                                intercept=inter,
+                                                divslope=slope))
         elif (slope, inter) == (None, 0):
             assert_array_equal(0,
                                write_return(arr, fobj, out_type,
@@ -663,34 +668,42 @@ def test_a2f_nan2zero_range():
         arr = np.array([-1, 0, 1, np.nan], dtype=dt)
         # Error occurs for arrays without nans too
         arr_no_nan = np.array([-1, 0, 1, 2], dtype=dt)
+        warn_type = np.ComplexWarning if np.issubdtype(dt, np.complexfloating) else None
         # No errors from explicit thresholding
         # mn thresholding excluding zero
-        assert_array_equal([1, 1, 1, 0],
-                           write_return(arr, fobj, np.int8, mn=1))
+        with pytest.warns(warn_type):
+            assert_array_equal([1, 1, 1, 0],
+                               write_return(arr, fobj, np.int8, mn=1))
         # mx thresholding excluding zero
-        assert_array_equal([-1, -1, -1, 0],
-                           write_return(arr, fobj, np.int8, mx=-1))
+        with pytest.warns(warn_type):
+            assert_array_equal([-1, -1, -1, 0],
+                               write_return(arr, fobj, np.int8, mx=-1))
         # Errors from datatype threshold after scaling
-        back_arr = write_return(arr, fobj, np.int8, intercept=128)
+        with pytest.warns(warn_type):
+            back_arr = write_return(arr, fobj, np.int8, intercept=128)
         assert_array_equal([-128, -128, -127, -128], back_arr)
         with pytest.raises(ValueError):
             write_return(arr, fobj, np.int8, intercept=129)
         with pytest.raises(ValueError):
             write_return(arr_no_nan, fobj, np.int8, intercept=129)
         # OK with nan2zero false, but we get whatever nan casts to
-        nan_cast = np.array(np.nan, dtype=dt).astype(np.int8)
-        back_arr = write_return(arr, fobj, np.int8, intercept=129, nan2zero=False)
+        with pytest.warns(warn_type):
+            nan_cast = np.array(np.nan, dtype=dt).astype(np.int8)
+        with pytest.warns(warn_type):
+            back_arr = write_return(arr, fobj, np.int8, intercept=129, nan2zero=False)
         assert_array_equal([-128, -128, -128, nan_cast], back_arr)
         # divslope
-        back_arr = write_return(arr, fobj, np.int8, intercept=256, divslope=2)
+        with pytest.warns(warn_type):
+            back_arr = write_return(arr, fobj, np.int8, intercept=256, divslope=2)
         assert_array_equal([-128, -128, -128, -128], back_arr)
         with pytest.raises(ValueError):
             write_return(arr, fobj, np.int8, intercept=257.1, divslope=2)
         with pytest.raises(ValueError):
             write_return(arr_no_nan, fobj, np.int8, intercept=257.1, divslope=2)
         # OK with nan2zero false
-        back_arr = write_return(arr, fobj, np.int8,
-                                intercept=257.1, divslope=2, nan2zero=False)
+        with pytest.warns(warn_type):
+            back_arr = write_return(arr, fobj, np.int8,
+                                    intercept=257.1, divslope=2, nan2zero=False)
         assert_array_equal([-128, -128, -128, nan_cast], back_arr)
 
 
@@ -1125,7 +1138,7 @@ def test_dtypes():
     dtr = make_dt_codes(dt_defs)
     assert dtr[np.dtype('f4').newbyteorder('S')] == 16
     assert dtr.value_set() == set((16,))
-    assert dtr.fields == ('code', 'label', 'type', 'niistring', 'dtype', 
+    assert dtr.fields == ('code', 'label', 'type', 'niistring', 'dtype',
                           'sw_dtype')
     assert dtr.niistring[16] == 'ASTRING'
     # And that unequal elements raises error
@@ -1224,9 +1237,8 @@ def test_array_from_file_overflow():
         array_from_file(shape, np.int8, NoStringIO())
     except IOError as err:
         message = str(err)
-    assert message == 'Expected {0} bytes, got {1} bytes from {2}\n' \
-                      ' - could the file be damaged?'.format(
-                      11390625000000000000, 0, 'object')
+    assert message == ("Expected 11390625000000000000 bytes, got 0 "
+                       "bytes from object\n - could the file be damaged?")
 
 
 def test__ftype4scaled_finite_warningfilters():
@@ -1279,7 +1291,7 @@ def test__ftype4scaled_finite_warningfilters():
 
 
 def _calculate_scale(data, out_dtype, allow_intercept):
-    ''' Calculate scaling and optional intercept for data
+    """ Calculate scaling and optional intercept for data
 
     Copy of the deprecated volumeutils.calculate_scale, to preserve tests
 
@@ -1303,7 +1315,7 @@ def _calculate_scale(data, out_dtype, allow_intercept):
     mx : None or float
        minimum of finite value in data, or None if this will not
        be used to threshold data
-    '''
+    """
     # Code here is a compatibility shell around arraywriters refactor
     in_dtype = data.dtype
     out_dtype = np.dtype(out_dtype)
