@@ -103,7 +103,7 @@ class DataError(Exception):
                         'nibabel.streamlines.load, instead.',
                         since='2.5.0', until='4.0.0')
 def read(fileobj, as_generator=False, points_space=None, strict=True):
-    ''' Read trackvis file from `fileobj`, return `streamlines`, `header`
+    """ Read trackvis file from `fileobj`, return `streamlines`, `header`
 
     Parameters
     ----------
@@ -152,7 +152,7 @@ def read(fileobj, as_generator=False, points_space=None, strict=True):
     coordinates, ``x, y, z``, where ``x`` is the floating point voxel
     coordinate along the first image axis, multiplied by the voxel size for
     that axis.
-    '''
+    """
     fileobj = ImageOpener(fileobj)
     hdr_str = fileobj.read(header_2_dtype.itemsize)
     # try defaulting to version 2 format
@@ -167,8 +167,7 @@ def read(fileobj, as_generator=False, points_space=None, strict=True):
     else:
         hdr = hdr.newbyteorder()
         if hdr['hdr_size'] != 1000:
-            raise HeaderError('Invalid hdr_size of %s'
-                              % hdr['hdr_size'])
+            raise HeaderError(f"Invalid hdr_size of {hdr['hdr_size']}")
         endianness = swapped_code
     # Check version and adapt structure accordingly
     version = hdr['version']
@@ -222,9 +221,8 @@ def read(fileobj, as_generator=False, points_space=None, strict=True):
                 actual_n_pts = int(len(pts_str) / pt_size)
                 if actual_n_pts != n_pts:
                     if strict:
-                        raise DataError('Expecting {0} points for stream {1}, '
-                                        'found {2}'.format(
-                                            n_pts, n_streams, actual_n_pts))
+                        raise DataError(f'Expecting {n_pts} points for stream '
+                                        f'{n_streams}, found {actual_n_pts}')
                     n_pts = actual_n_pts
                     end_of_file = True
             # Cast bytes to points array
@@ -248,8 +246,7 @@ def read(fileobj, as_generator=False, points_space=None, strict=True):
         # Raise error if we didn't get as many streams as claimed
         if n_streams_required != np.inf and n_streams < n_streams_required:
             raise DataError(
-                'Expecting {0} streamlines, found only {1}'.format(
-                    stream_count, n_streams))
+                f'Expecting {stream_count} streamlines, found only {n_streams}')
 
     streamlines = track_gen()
     if not as_generator:
@@ -262,7 +259,7 @@ def read(fileobj, as_generator=False, points_space=None, strict=True):
                         since='2.5.0', until='4.0.0')
 def write(fileobj, streamlines, hdr_mapping=None, endianness=None,
           points_space=None):
-    ''' Write header and `streamlines` to trackvis file `fileobj`
+    """ Write header and `streamlines` to trackvis file `fileobj`
 
     The parameters from the streamlines override conflicting parameters
     in the `hdr_mapping` information.  In particular, the number of
@@ -356,7 +353,7 @@ def write(fileobj, streamlines, hdr_mapping=None, endianness=None,
     This information comes from some helpful replies on the trackvis forum
     about `interpreting point coordiantes
     <http://trackvis.org/blog/forum/diffusion-toolkit-usage/interpretation-of-track-point-coordinates>`_
-    '''
+    """
     stream_iter = iter(streamlines)
     try:
         streams0 = next(stream_iter)
@@ -428,8 +425,7 @@ def write(fileobj, streamlines, hdr_mapping=None, endianness=None,
                 raise DataError('Expecting 0 scalars per point')
         else:
             if scalars.shape != (n_pts, n_s):
-                raise DataError('Scalars should be shape (%s, %s)' %
-                                (n_pts, n_s))
+                raise DataError(f'Scalars should be shape ({n_pts}, {n_s})')
             if scalars.dtype != f4dt:
                 scalars = scalars.astype(f4dt)
             pts = np.c_[pts, scalars]
@@ -439,7 +435,7 @@ def write(fileobj, streamlines, hdr_mapping=None, endianness=None,
                 raise DataError('Expecting 0 properties per point')
         else:
             if props.size != n_p:
-                raise DataError('Properties should be size %s' % n_p)
+                raise DataError(f'Properties should be size {n_p}')
             if props.dtype != f4dt:
                 props = props.astype(f4dt)
             fileobj.write(props.tobytes())
@@ -474,13 +470,13 @@ def _check_hdr_points_space(hdr, points_space):
     if points_space == 'voxel':
         voxel_size = hdr['voxel_size']
         if np.any(voxel_size < 0):
-            raise HeaderError('Negative voxel sizes %s not valid for voxel - '
-                              'voxmm conversion' % voxel_size)
+            raise HeaderError(f'Negative voxel sizes {voxel_size} not '
+                              'valid for voxel - voxmm conversion')
         if np.all(voxel_size == 0):
             raise HeaderError('Cannot convert between voxels and voxmm when '
                               '"voxel_sizes" all 0')
         if np.any(voxel_size == 0):
-            warnings.warn('zero values in "voxel_size" - %s' % voxel_size)
+            warnings.warn(f'zero values in "voxel_size" - {voxel_size}')
         return
     elif points_space == 'rasmm':
         try:
@@ -495,23 +491,21 @@ def _check_hdr_points_space(hdr, points_space):
         zooms = hdr['voxel_size']
         aff_zooms = np.sqrt(np.sum(affine[:3, :3]**2, axis=0))
         if not np.allclose(aff_zooms, zooms):
-            raise HeaderError('Affine zooms %s differ from voxel_size '
-                              'field value %s' % (aff_zooms, zooms))
+            raise HeaderError(f'Affine zooms {aff_zooms} differ '
+                              f'from voxel_size field value {zooms}')
         aff_order = ''.join(aff2axcodes(affine))
         voxel_order = asstr(hdr['voxel_order'].item())
         if voxel_order == '':
             voxel_order = 'LPS'  # trackvis default
         if not voxel_order == aff_order:
-            raise HeaderError('Affine implies voxel_order %s but '
-                              'header voxel_order is %s' %
-                              (aff_order, voxel_order))
+            raise HeaderError(f'Affine implies voxel_order {aff_order} '
+                              f'but header voxel_order is {voxel_order}')
     else:
-        raise ValueError('Painfully confusing "points_space" value of "%s"'
-                         % points_space)
+        raise ValueError(f'Painfully confusing "points_space" value of "{points_space}"')
 
 
 def _hdr_from_mapping(hdr=None, mapping=None, endianness=native_code):
-    ''' Fill `hdr` from mapping `mapping`, with given endianness '''
+    """ Fill `hdr` from mapping `mapping`, with given endianness """
     if hdr is None:
         # passed a valid mapping as header?  Copy and return
         if isinstance(mapping, np.ndarray):
@@ -546,7 +540,7 @@ def _hdr_from_mapping(hdr=None, mapping=None, endianness=native_code):
                         'nibabel.streamlines.TrkFile.create_empty_header, instead.',
                         since='2.5.0', until='4.0.0')
 def empty_header(endianness=None, version=2):
-    ''' Empty trackvis header
+    """ Empty trackvis header
 
     Parameters
     ----------
@@ -583,7 +577,7 @@ def empty_header(endianness=None, version=2):
     missing.  We make no attempt to fill it with sensible defaults on
     the basis that, if the information is missing, it is better to be
     explicit.
-    '''
+    """
     if version == 1:
         dt = header_1_dtype
     elif version == 2:
@@ -603,7 +597,7 @@ def empty_header(endianness=None, version=2):
                         'nibabel.streamlines.trk.get_affine_trackvis_to_rasmm, instead.',
                         since='2.5.0', until='4.0.0')
 def aff_from_hdr(trk_hdr, atleast_v2=True):
-    ''' Return voxel to mm affine from trackvis header
+    """ Return voxel to mm affine from trackvis header
 
     Affine is mapping from voxel space to Nifti (RAS) output coordinate
     system convention; x: Left -> Right, y: Posterior -> Anterior, z:
@@ -636,7 +630,7 @@ def aff_from_hdr(trk_hdr, atleast_v2=True):
     allow negative voxel sizes (needed for recording axis flips) and sets the
     origin field to 0. In future, we'll raise an error rather than try and
     estimate the affine from version 1 fields
-    '''
+    """
     if trk_hdr['version'] == 2:
         aff = trk_hdr['vox_to_ras']
         if aff[3, 3] != 0:
@@ -675,7 +669,7 @@ def aff_from_hdr(trk_hdr, atleast_v2=True):
         exp_order = ''.join(aff2axcodes(aff))
         if voxel_order != exp_order:
             raise HeaderError('Estimate of header affine does not match '
-                              'voxel_order of %s' % exp_order)
+                              f'voxel_order of {exp_order}')
     return aff
 
 
@@ -683,7 +677,7 @@ def aff_from_hdr(trk_hdr, atleast_v2=True):
                         'nibabel.streamlines.TrkFile.affine_to_rasmm property, instead.',
                         since='2.5.0', until='4.0.0')
 def aff_to_hdr(affine, trk_hdr, pos_vox=True, set_order=True):
-    ''' Set affine `affine` into trackvis header `trk_hdr`
+    """ Set affine `affine` into trackvis header `trk_hdr`
 
     Affine is mapping from voxel space to Nifti RAS) output coordinate
     system convention; x: Left -> Right, y: Posterior -> Anterior, z:
@@ -723,7 +717,7 @@ def aff_to_hdr(affine, trk_hdr, pos_vox=True, set_order=True):
     reliably.  It turns out that negative flips upset trackvis (the
     application).  The application also ignores the origin field, and may not
     use the 'image_orientation_patient' field.
-    '''
+    """
     try:
         version = trk_hdr['version']
     except (KeyError, ValueError):  # dict or structured array
@@ -765,7 +759,7 @@ class TrackvisFileError(Exception):
 
 
 class TrackvisFile(object):
-    ''' Convenience class to encapsulate trackvis file information
+    """ Convenience class to encapsulate trackvis file information
 
     Parameters
     ----------
@@ -792,7 +786,7 @@ class TrackvisFile(object):
         Affine expressing relationship of voxels in an image to mm in RAS mm
         space. If 'points_space' is not None, you can use this to give the
         relationship between voxels, rasmm and voxmm space (above).
-    '''
+    """
 
     @deprecate_with_version('TrackvisFile is deprecated; please use '
                             'nibabel.streamlines.TrkFile, instead.',
